@@ -1,41 +1,41 @@
 /*
  *  export_toolame.c
  *
- *  Andreas Neukoetter <anti@webhome.de> - April 2002 
+ *  Andreas Neukoetter <anti@webhome.de> - April 2002
  *  sox extension: Christian Vogelgsang <Vogelgsang@informatik.uni-erlangen.de>
  *
  *  based on export mp2enc.c
  *
  *  This file is part of transcode, a video stream processing tool
- *      
+ *
  *  transcode is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2, or (at your option)
  *  any later version.
- *   
+ *
  *  transcode is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
- *   
+ *
  *  You should have received a copy of the GNU General Public License
  *  along with GNU Make; see the file COPYING.  If not, write to
- *  the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA. 
+ *  the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  */
 
+#define MOD_NAME    "export_toolame.so"
+#define MOD_VERSION "v1.0.6 (2004-01-26)"
+#define MOD_CODEC   "(audio) MPEG 1/2"
+
+#include "transcode.h"
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <sys/stat.h>
 #include <unistd.h>
 #include <fcntl.h>
 
-#include "transcode.h"
-
-#define MOD_NAME    "export_toolame.so"
-#define MOD_VERSION "v1.0.6 (2004-01-26)"
-#define MOD_CODEC   "(audio) MPEG 1/2"
-
 static int 			verbose_flag	= TC_QUIET;
 static int 			capability_flag	= TC_CAP_PCM;
 
@@ -44,9 +44,9 @@ static int 			capability_flag	= TC_CAP_PCM;
 
 static FILE* 			pFile 		= NULL;
 
-/* ------------------------------------------------------------ 
+/* ------------------------------------------------------------
  *
- * Pipe write helper function 
+ * Pipe write helper function
  *
  * ------------------------------------------------------------*/
 
@@ -56,18 +56,18 @@ static int p_write (char *buf, size_t len)
     size_t r  = 0;
     int    fd = fileno (pFile);
 
-    while (r < len) 
+    while (r < len)
     {
         if ((n = write (fd, buf + r, len - r)) < 0)
 	    return n;
-      
+
         r += n;
     }
-   
+
     return r;
 }
 
-/* ------------------------------------------------------------ 
+/* ------------------------------------------------------------
  *
  * open outputfile
  *
@@ -83,11 +83,11 @@ MOD_open
     //int ofreq_dec;
     int ochan;
     char chan;
-    char *ptr = buf;
+    char *ptr;
 
     /* check for toolame */
     if (tc_test_program("toolame") != 0) return (TC_EXPORT_ERROR);
-        
+
     /* verbose? */
     verb = (verbose & TC_DEBUG) ? 2:0;
 
@@ -106,13 +106,15 @@ MOD_open
     if(ofreq!=ifreq) {
       /* check for sox */
       if (tc_test_program("sox") != 0) return (TC_EXPORT_ERROR);
-            
+
       /* add sox for conversion */
-      snprintf(buf, sizeof(buf), "sox %s -r %d -c %d -t raw - -r %d -t raw - polyphase "
-	      "2>/dev/null | ",
-	      (vob->dm_bits==16)?"-w -s":"-b -u", 
-	      ifreq, ochan, ofreq);
+      tc_snprintf(buf, sizeof(buf), "sox %s -r %d -c %d -t raw - -r %d"
+		  " -t raw - polyphase 2>/dev/null | ",
+		  (vob->dm_bits==16)?"-w -s":"-b -u",
+		  ifreq, ochan, ofreq);
       ptr = buf + strlen(buf);
+    } else {
+      ptr = buf;
     }
 
     /* convert output frequency to fixed point */
@@ -120,29 +122,31 @@ MOD_open
     ofreq_int = ofreq/1000.0;
     ofreq_dec = ofreq-ofreq_int*1000;
     */
-	    
+
     /* toolame command line */
-    /* ptr is a pointer to buf */
-    snprintf(ptr, sizeof(buf), "toolame -s %0.3f -b %d -m %c - \"%s.mp2\" 2>/dev/null %s", 
-	    (double)ofreq/1000.0, orate, chan, vob->audio_out_file, (vob->ex_a_string?vob->ex_a_string:""));
-	
-    fprintf (stderr,"[%s] cmd=%s\n", MOD_NAME, buf);
-    
+    /* ptr is a pointer into buf */
+    tc_snprintf(ptr, sizeof(buf) - (ptr-buf),
+		"toolame -s %0.3f -b %d -m %c - \"%s\" 2>/dev/null %s",
+		(double)ofreq/1000.0, orate, chan, vob->audio_out_file,
+		(vob->ex_a_string?vob->ex_a_string:""));
+
+    tc_log_info (MOD_NAME, "%s", buf);
+
     if ((pFile = popen (buf, "w")) == NULL)
       return(TC_EXPORT_ERROR);
-  
+
     return(0);
   }
-  
-  if (param->flag == TC_VIDEO) 
+
+  if (param->flag == TC_VIDEO)
     return(0);
-  
+
   // invalid flag
-  return(TC_EXPORT_ERROR); 
+  return(TC_EXPORT_ERROR);
 }
 
 
-/* ------------------------------------------------------------ 
+/* ------------------------------------------------------------
  *
  * init codec
  *
@@ -150,19 +154,19 @@ MOD_open
 
 MOD_init
 {
-    if(param->flag == TC_AUDIO) 
+    if(param->flag == TC_AUDIO)
     {
         return(0);
     }
-  
-    if (param->flag == TC_VIDEO) 
-	return(0);  
-  
+
+    if (param->flag == TC_VIDEO)
+	return(0);
+
     // invalid flag
-    return(TC_EXPORT_ERROR); 
+    return(TC_EXPORT_ERROR);
 }
 
-/* ------------------------------------------------------------ 
+/* ------------------------------------------------------------
  *
  * encode and export frame
  *
@@ -173,59 +177,59 @@ MOD_encode
 {
     if(param->flag == TC_AUDIO)
     {
-        if (p_write (param->buffer, param->size) != param->size) 
-        {    
-            perror("write audio frame");
+        if (p_write (param->buffer, param->size) != param->size)
+        {
+            tc_log_perror(MOD_NAME, "write audio frame");
             return(TC_EXPORT_ERROR);
-        }      
-        return (0); 
+        }
+        return (0);
     }
-  
-    if (param->flag == TC_VIDEO) 
+
+    if (param->flag == TC_VIDEO)
         return(0);
 
     // invalid flag
-    return(TC_EXPORT_ERROR); 
+    return(TC_EXPORT_ERROR);
 }
 
-/* ------------------------------------------------------------ 
+/* ------------------------------------------------------------
  *
  * stop encoder
  *
  * ------------------------------------------------------------*/
 
 MOD_stop
-{  
-    if (param->flag == TC_VIDEO) 
+{
+    if (param->flag == TC_VIDEO)
         return (0);
-  
-    if (param->flag == TC_AUDIO) 
+
+    if (param->flag == TC_AUDIO)
 	return (0);
-  
-    return(TC_EXPORT_ERROR);     
+
+    return(TC_EXPORT_ERROR);
 }
 
-/* ------------------------------------------------------------ 
+/* ------------------------------------------------------------
  *
  * close codec
  *
  * ------------------------------------------------------------*/
 
 MOD_close
-{  
-    if (param->flag == TC_VIDEO) 
+{
+    if (param->flag == TC_VIDEO)
 	return (0);
-  
-    if (param->flag == TC_AUDIO) 
+
+    if (param->flag == TC_AUDIO)
     {
-        if (pFile) 
+        if (pFile)
 	  pclose (pFile);
-    
+
 	pFile = NULL;
-  
+
         return(0);
     }
-  
-    return (TC_EXPORT_ERROR); 
+
+    return (TC_EXPORT_ERROR);
 }
 
