@@ -1,8 +1,8 @@
 #ifndef __FFMPEG_CFG_H
 #define __FFMPEG_CFG_H
 
-#include "../libioaux/configs.h"
-#include "../ffmpeg/libavcodec/avcodec.h"
+#include "libtc/cfgfile.h"
+#include "libtc/tcavcodec.h"
 
 //char *lavc_param_vcodec = "mpeg4";
 //extern int lavc_param_vbitrate;
@@ -15,10 +15,8 @@ extern int lavc_param_vme;
 //extern int lavc_param_vqmax;
 extern int lavc_param_mb_qmin;
 extern int lavc_param_mb_qmax;
-#if LIBAVCODEC_BUILD > 4694
 extern int lavc_param_lmin;
 extern int lavc_param_lmax;
-#endif
 extern int lavc_param_vqdiff;
 extern float lavc_param_vqcompress;
 extern float lavc_param_vqblur;
@@ -50,8 +48,6 @@ extern float lavc_param_rc_initial_cplx;
 extern int lavc_param_mpeg_quant;
 extern int lavc_param_fdct;
 extern int lavc_param_idct;
-extern char* lavc_param_aspect;
-extern int lavc_param_autoaspect; // FLAG
 extern float lavc_param_lumi_masking;
 extern float lavc_param_dark_masking;
 extern float lavc_param_temporal_cplx_masking;
@@ -67,6 +63,7 @@ extern int lavc_param_me_pre_cmp;
 extern int lavc_param_me_cmp;
 extern int lavc_param_me_sub_cmp;
 extern int lavc_param_mb_cmp;
+extern int lavc_param_ildct_cmp;
 extern int lavc_param_pre_dia_size;
 extern int lavc_param_dia_size;
 extern int lavc_param_qpel;
@@ -87,7 +84,22 @@ extern int lavc_param_cbp;
 extern int lavc_param_mv0;
 extern int lavc_param_noise_reduction;
 extern int lavc_param_qp_rd;
+extern int lavc_param_inter_threshold;
+extern int lavc_param_sc_threshold;
+extern int lavc_param_ss;
+extern int lavc_param_top;
+extern int lavc_param_alt;
+extern int lavc_param_ilme;
+extern int lavc_param_scan_offset;
+extern int lavc_param_threads;
+extern int lavc_param_gmc;
+extern int lavc_param_trunc;
+extern int lavc_param_fps_code;
+extern int lavc_param_closedgop;
+extern int lavc_param_intra_dc_precision;
+extern int lavc_param_skip_top;
+extern int lavc_param_skip_bottom;
 
-extern struct config lavcopts_conf[];
+extern TCConfigEntry lavcopts_conf[];
 
 #endif
